Welcome to gojot's documentation!
======================================

.. toctree::
   :maxdepth: 2

   about
   installation
   usage

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
